from setuptools import find_packages, setup

setup(
    name='infi_const',
    packages=find_packages(),
    version='0.0.11',
    description='Const package for infinity team',
    author='Infinity Team',
    install_requires=[],
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
)