class UtilsConsts:
    EMAIL_LIST_NAVAD: list[str] = ["liorfranko587@gmail.com, amit.shwartz01@gmail.com, itay@skylinesoft.com,\
                            ronik1917@gmail.com, Daniel@iit.co.il, Bason_tehila@hotmail.com,\
                            Ronnie@skylinesoft.com, liorcliorc@gmail.com, razraz2711@gmail.com,\
                            shmuelmorr@gmail.com, shacharba@matrix.co.il, stamdvarim1000@gmail.com,\
                            Rotembh20000@gmail.com"]

    EMAIL_TEST_LIST: list[str] = ["infinitymailbox9900@gmail.com,stamdvarim1000@gmail.com"]

    AZCOPY_QUEUE: str = "azcopy_q"

    FLIGHTS_RECORD_QUEUE: str = "flights_record_q"

    FLIGHTS_HISTORY_QUEUE: str = "flights_history_q"

    FLIGHTS_RECORD_SKYLINE_COLUMN: str = "SkylineInit"

    TGV_VALIDATIONS_QUEUE: str = "tgv_q"

    PREPROCESS_QUEUE: str = "pre_q"

    FAILED_FLIGHTS_RECORD_QUEUE: str = "failed_flights_record_q"

    FAILED_FLIGHTS_HISTORY_QUEUE: str = "failed_flights_history_q"

    FAILED_TGV_VALIDATIONS_QUEUE: str = "failed_tgv_q"

    FAILED_PREPROCESS_QUEUE: str = "failed_pre_q"

    FAILED_AZCOPY_QUEUE: str = "failed_azcopy_q"

    API_PORT: int = 8080

    STATUS_LIST: list = ["DMZ", "SkylineInit", "AT", "Mesh", "Upload"]

    COLUMNS_DB: list = [
        "NAME",
        "TYPE_GIHA",
        "DAY",
        "MONTH",
        "YEAR",
        "OVERLAP",
        "TAIL_NUMBER",
        "PAYLOAD_NUMBER",
        "PAYLOAD_DIGITS",
        "FLIGHT_NUMBER",
        "NUM_PIC",
    ]
